# Authors

  - Maxime Lecomte - https://team.inria.fr/pleiade
  - Coralie Muller - https://team.inria.fr/pleiade
  - Ariane Badoual
  - Hélène Falentin
  - David James Sherman - https://team.inria.fr/pleiade
  - Clémence Frioux - https://team.inria.fr/pleiade
